@@ -205,6 +205,8 @@ class LucidStreamHandler(logging.StreamHandler):
             self.stream.write(self.return_carriage + logging.loading_bar.get_bar() + self.return_carriage)
 
 
+add_logging_level("INIT", 15)
+add_loading_bar(LucidLoadingBar())
 lucid_rotating_file_handler = LucidTimedRotatingFileHandler(
     directory=LOG_DIRECTORY,
     when=LOG_ROTATION_TIME,
